function [successful] = gaalopscriptCellArr2Matlab(gaalopscript, scriptName)
    % Compiles a GAALOPScript with the given contents with GAALOPWeb and creates a MATLAB file with the given script name.
    %
    % Convenience function, using function gaalopwebCompile().
    % 
    % HINT: This script will do a download of the generated script. Maybe your antivirus software will detect the program as an IPC.Generic malware.
    %
    % Input:
    %   gaalopscript: (cell array) The gaalopscript source, that should be compiled with GAALOPWeb
    %   scriptName: (string) The name of the generated script. The file, which is generated, is {scriptName}.m
    % Output:
    %   successful: (boolean) Was the compilation with GAALOPWeb successful?
    % Written by Christian Steinmetz.
	% Version 1.0, 16.04.2020

    % create temp file
    tempFilename = strrep([tempname,'.clu'], "\\", "/");
    fid = fopen(tempFilename, 'w'); 
    fprintf(fid, '%s\n',gaalopscript{:}) ;
    fclose(fid);

    % destination file is the scriptName with Matlab filename ending
    destinationFilename = strcat(scriptName, ".m");
    
    [successful] = gaalopwebCompile(tempFilename, scriptName, destinationFilename);

    % delete temp file
    delete(tempFilename);
end
