function [successful] = gaalopwebCompile(gaalopscriptFilename, scriptName, destinationFilename)
    % Compiles a GAALOPScript file at {gaalopscriptFilename} with GAALOPWeb using the script name {scriptName} and creates a MATLAB file
    % at {destinationFilename}
    %
    % HINT: This script will do a download of the generated script. Maybe your antivirus software will detect the program as an IPC.Generic malware.
    %
    % Input:
    %   gaalopscriptFilename: The filename including path of the GAALOPScript file, that should be compiled with GAALOPWeb
    %   scriptName: The name of the script, without ".clu"
    %   destinationFilename: The filename including path of the generated
    %   file
    % Output:
    %   successful: (boolean) Was the compilation with GAALOPWeb successful?
    %
    % Written by Christian Steinmetz.
	% Version 1.0, 16.04.2020
    
    % the base URL of the GAALOPWeb API with trailing slash
    baseUrl = "https://gaalopweb.esa.informatik.tu-darmstadt.de/gaalopweb/res/";
    
    disp("GAALOPScript will be uploaded now! Please wait.");
    
    % Start compilation using CURL
    [~, response] = system(strcat('curl -X POST -H "Content-Type: text/plain" --data-binary "@', gaalopscriptFilename, '" "', baseUrl, "api/compile", "?InputScript=", scriptName, '.clu&CodeGenerator=de.gaalop.matlab.Plugin"'));
    % EXAMPLE: response = '{ "status": "insertedInQueue", "id": "118...fde" }';
    
    % Get ID of compilation
    names = regexp(response,'{.*"id":[^"]*"(?<id>[^"]+)".*}','names'); 
    id = names.id;

    disp(strcat("Compilation started using the ID ",id,"! Please wait for the result."));

    % Wait on result compilationSucceeded or compilationException and check this each second
    progress = true;
    while progress
        pause(1);

        % Get current status of compilation
        response = urlread(strcat(baseUrl, "api/result/", id));
        names = regexp(response,'{.*"status":[^"]*"(?<status>[^"]+)".*}','names');
        status = names.status;

        % if compilation has ended successful, end the loop
        if strcmp(status, "compilationSucceeded")
            progress = false;
        end

        % if compilation has ended with errors, abort the function
        if strcmp(status, "compilationException")
            disp(strcat("Compilation was NOT successful. You can find an error description on ",baseUrl,"cpp/result?id=",id));
            successful = false;
            return
        end
    end

    disp(strcat("Compilation was successful. You will find the generated code in the file: ", destinationFilename));

    % Write result to destination file
    urlwrite(strcat(baseUrl, "api/result/", id, "/0"), destinationFilename);

    successful = true;
end